@@ -1,7 +1,6 @@
+use crate::handlebars_engine::deserialize_context::deserialize_context;
 use crate::out_model::class::Class;
 use handlebars::{Context, Handlebars, Helper, HelperResult, Output, RenderContext, RenderError};
-use serde::de::IntoDeserializer;
-use serde::Deserialize;
 
 pub fn cantrips_known(
     h: &Helper,
@@ -10,8 +9,7 @@ pub fn cantrips_known(
     _: &mut RenderContext,
     out: &mut dyn Output,
 ) -> HelperResult {
-    let class = Class::deserialize(ctx.data().clone().into_deserializer())
-        .map_err(|x| RenderError::new(x.to_string()))?;
+    let class = deserialize_context::<Class>(ctx)?.inner;
     let level = h
         .param(0)
         .ok_or_else(|| RenderError::new("param not found"))?
