@@ -1,8 +1,7 @@
+use crate::handlebars_engine::deserialize_context::deserialize_context;
 use crate::out_model::class::feature::Feature;
 use crate::out_model::class::Class;
 use handlebars::{HelperDef, RenderError, ScopedJson};
-use serde::de::IntoDeserializer;
-use serde::Deserialize;
 
 #[allow(non_camel_case_types)]
 pub struct features_at_level;
@@ -16,8 +15,7 @@ impl HelperDef for features_at_level {
         ctx: &'rc ::handlebars::Context,
         _: &mut ::handlebars::RenderContext<'reg, 'rc>,
     ) -> Result<::handlebars::ScopedJson<'reg, 'rc>, ::handlebars::RenderError> {
-        let class = Class::deserialize(ctx.data().clone().into_deserializer())
-            .map_err(|x| RenderError::new(x.to_string()))?;
+        let class = deserialize_context::<Class>(ctx)?.inner;
         let level = h
             .param(0)
             .ok_or_else(|| RenderError::new("param not found"))?
