@@ -1,7 +1,6 @@
+use crate::handlebars_engine::deserialize_context::deserialize_context;
 use crate::out_model::class::Class;
-use handlebars::{HelperDef, JsonValue, RenderError, ScopedJson};
-use serde::de::IntoDeserializer;
-use serde::Deserialize;
+use handlebars::{HelperDef, JsonValue, ScopedJson};
 
 #[allow(non_camel_case_types)]
 pub struct has_cantrips;
@@ -15,8 +14,7 @@ impl HelperDef for has_cantrips {
         ctx: &'rc ::handlebars::Context,
         _: &mut ::handlebars::RenderContext<'reg, 'rc>,
     ) -> Result<::handlebars::ScopedJson<'reg, 'rc>, ::handlebars::RenderError> {
-        let class = Class::deserialize(ctx.data().clone().into_deserializer())
-            .map_err(|x| RenderError::new(x.to_string()))?;
+        let class = deserialize_context::<Class>(ctx)?.inner;
         Ok(ScopedJson::Derived(JsonValue::Bool(
             class.start_cantrips_known.is_some(),
         )))
