@@ -12,7 +12,7 @@ pub fn format_componenets(
 ) -> HelperResult {
     let component = Components::deserialize(
         h.param(0)
-            .ok_or(RenderError::new("param not found"))?
+            .ok_or_else(||RenderError::new("param not found"))?
             .value()
             .clone()
             .into_deserializer(),
