@@ -8,7 +8,7 @@ impl From<In> for Out {
             In::Half => Out::Half,
             In::Artificer => Out::Artificer,
             In::None => Out::None,
-            In::Third => Out::Thrid
+            In::Third => Out::Thrid,
         }
     }
 }
