@@ -1,10 +1,11 @@
 use serde::{Deserialize, Serialize};
 
-use super::feature::Feature;
+use super::{caster_type::CasterType, feature::Feature};
 
-#[derive(Debug, Deserialize, Serialize)]
+#[derive(Debug, Clone, Deserialize, Serialize)]
 pub struct Subclass {
     pub name: String,
     pub flavour_text: String,
     pub features: Vec<Feature>,
+    pub caster_type: CasterType,
 }
