@@ -3,7 +3,7 @@ use std::borrow::Cow;
 use std::path::PathBuf;
 
 use once_cell::sync::Lazy;
-use regex::Regex;
+use regex::{Captures, Regex};
 
 pub fn is_vowel(c: char) -> bool {
     matches!(c, 'a' | 'e' | 'i' | 'o' | 'u' | 'y')
@@ -39,5 +39,17 @@ pub fn path_normalize(path: PathBuf) -> PathBuf {
 
 pub fn file_name_sanitize<S: AsRef<str>>(s: S) -> String {
     static REGEX: Lazy<Regex> = Lazy::new(|| Regex::new(r#"(?:/|<|>|:|"|\\|\||\?|\*)"#).unwrap());
-    REGEX.replace(s.as_ref(), "_").into()
+    REGEX.replace_all(s.as_ref(), "_").into()
 }
+
+pub fn class_name_sanitize<S: AsRef<str>>(s: S) -> String{
+    static REGEX: Lazy<Regex> = Lazy::new(|| Regex::new(r"[^a-zA-Z0-9]").unwrap());
+    REGEX.replace_all(s.as_ref(), "").into()
+}
+
+pub fn proper_noun<S: AsRef<str>>(s: S) -> String {
+    static REGEX: Lazy<Regex> = Lazy::new(||Regex::new(r"(?:^|[^a-zA-Z1-9])[a-zA-Z1-9]").unwrap());
+    REGEX.replace_all(s.as_ref(), |caps: &Captures| {
+        caps[0].to_uppercase()
+    }).into()
+}
\ No newline at end of file
